==> Data-Sah-Filter-0.011.tar.gz: Data-Sah-Filter-0.011/lib/Data/Sah/Filter/perl/Array/remove_undef.pm <==
package Data::Sah::Filter::perl::Array::remove_undef;

use 5.010001;
use strict;
use warnings;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2022-07-16'; # DATE
our $DIST = 'Data-Sah-Filter'; # DIST
our $VERSION = '0.011'; # VERSION

sub meta {
    +{
        v => 1,
        summary => 'Remove undef elements from an array',
        target_type => 'array',
        args => {
        },
        examples => [
            {value=>[]},
            {value=>["a","b"]},
            {value=>["a","b",undef,"a",undef], filtered_value=>["a","b","a"]},
        ],
    };
}

sub filter {
    my %fargs = @_;

    my $dt = $fargs{data_term};
    my $res = {};
    $res->{expr_filter} = join(
        "",
        "[grep {defined} \@{ $dt }]",
    );

    $res;
}

1;
# ABSTRACT: Remove undef elements from an array

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Sah::Filter::perl::Array::remove_undef - Remove undef elements from an array

=head1 VERSION

This document describes version 0.011 of Data::Sah::Filter::perl::Array::remove_undef (from Perl distribution Data-Sah-Filter), released on 2022-07-16.

=head1 SYNOPSIS

=head2 Using in Sah schema's C<prefilters> (or C<postfilters>) clause

 ["array","prefilters",[["Array::remove_undef"]]]

=head2 Using with L<Data::Sah>:

 use Data::Sah qw(gen_validator);
 
 my $schema = ["array","prefilters",[["Array::remove_undef"]]];
 my $validator = gen_validator($schema);
 if ($validator->($some_data)) { print 'Valid!' }

=head2 Using with L<Data::Sah:Filter> directly:

 use Data::Sah::Filter qw(gen_filter);

 my $filter = gen_filter([["Array::remove_undef"]]);
 my $filtered_value = $filter->($some_data);

=head2 Sample data and filtering results

 [] # valid, unchanged
 ["a","b"] # valid, unchanged
 ["a","b",undef,"a",undef] # valid, becomes ["a","b","a"]

=for Pod::Coverage ^(meta|filter)$

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-Filter>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Data-Sah-Filter>.

=head1 SEE ALSO

Related filters: L<Float::check_has_fraction|Data::Sah::Filter::perl::Float::check_has_fraction>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
beyond that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah-Filter>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut

==> Data-Sah-Filter-0.014.tar.gz: Data-Sah-Filter-0.014/lib/Data/Sah/Filter/perl/Array/remove_undef.pm <==
package Data::Sah::Filter::perl::Array::remove_undef;

use 5.010001;
use strict;
use warnings;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2022-10-17'; # DATE
our $DIST = 'Data-Sah-Filter'; # DIST
our $VERSION = '0.014'; # VERSION

sub meta {
    +{
        v => 1,
        summary => 'Remove undef elements from an array',
        target_type => 'array',
        args => {
        },
        examples => [
            {value=>[]},
            {value=>["a","b"]},
            {value=>["a","b",undef,"a",undef], filtered_value=>["a","b","a"]},
        ],
    };
}

sub filter {
    my %fargs = @_;

    my $dt = $fargs{data_term};
    my $res = {};
    $res->{expr_filter} = join(
        "",
        "[grep {defined} \@{ $dt }]",
    );

    $res;
}

1;
# ABSTRACT: Remove undef elements from an array

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Sah::Filter::perl::Array::remove_undef - Remove undef elements from an array

=head1 VERSION

This document describes version 0.014 of Data::Sah::Filter::perl::Array::remove_undef (from Perl distribution Data-Sah-Filter), released on 2022-10-17.

=head1 SYNOPSIS

=head2 Using in Sah schema's C<prefilters> (or C<postfilters>) clause

 ["array","prefilters",[["Array::remove_undef"]]]

=head2 Using with L<Data::Sah>:

 use Data::Sah qw(gen_validator);
 
 my $schema = ["array","prefilters",[["Array::remove_undef"]]];
 my $validator = gen_validator($schema);
 if ($validator->($some_data)) { print 'Valid!' }

=head2 Using with L<Data::Sah:Filter> directly:

 use Data::Sah::Filter qw(gen_filter);

 my $filter = gen_filter([["Array::remove_undef"]]);
 my $filtered_value = $filter->($some_data);

=head2 Sample data and filtering results

 [] # valid, unchanged
 ["a","b"] # valid, unchanged
 ["a","b",undef,"a",undef] # valid, becomes ["a","b","a"]

=for Pod::Coverage ^(meta|filter)$

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-Filter>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Data-Sah-Filter>.

=head1 SEE ALSO

Related filters: L<Float::check_has_fraction|Data::Sah::Filter::perl::Float::check_has_fraction>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah-Filter>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
